import React, { useState, useRef, Children } from 'react';
import { SandpackProvider, SandpackCodeEditor, SandpackThemeProvider, SandpackReactDevTools, useSandpack, useActiveCode } from '@codesandbox/sandpack-react';
import { SandpackLogLevel } from '@codesandbox/sandpack-client';
import NavigationBar from './NavigationBar';
import Preview from './Preview';
import IconChevron from './IconChevron';
import { createFileMap } from '../utils/createFileMap';
import { getDeps, getDevDeps, addOnFiles } from '../utils/getDeps';
import { sandpackStyle } from '../style';

function SandpackRoot(props) {
  var _files$AppCss$code, _files$AppCss;

  var children = props.children,
      code = props.code,
      filePath = props.filePath,
      frameWork = props.frameWork,
      dependencies = props.dependencies,
      editUrl = props.editUrl,
      theme = props.theme,
      _props$externalResour = props.externalResources,
      externalResources = _props$externalResour === void 0 ? [] : _props$externalResour;
  var template = frameWork || 'react';
  var sandpackProviderOptions = {
    autorun: true,
    logLevel: SandpackLogLevel.None,
    initMode: 'user-visible',
    initModeObserverOptions: {
      rootMargin: '1400px 0px'
    },
    externalResources: externalResources
  };
  var customSetup = {
    dependencies: getDeps(template, dependencies),
    devDependencies: getDevDeps(template),
    entry: '/src/app.ts'
  };
  var codeSnippets = Children.toArray(children);
  var files = createFileMap(codeSnippets);

  if (code) {
    var extraFilePath = "/src/pages/index/index." + (template === 'react' ? 'tsx' : 'vue');
    files[extraFilePath] = {
      code: code,
      active: true,
      hidden: false,
      editUrl: editUrl
    };

    if (filePath) {
      sandpackProviderOptions.activeFile = extraFilePath;
      sandpackProviderOptions.visibleFiles = [extraFilePath];
    }
  } // addon styles.css


  files['/src/app.css'] = {
    code: [sandpackStyle, (_files$AppCss$code = (_files$AppCss = files['/app.css']) == null ? void 0 : _files$AppCss.code) != null ? _files$AppCss$code : ''].join('\n\n'),
    hidden: true
  }; // add extra setting files

  files = addOnFiles(files, template);
  return /*#__PURE__*/React.createElement("div", {
    className: "taro-hooks--sandpack",
    translate: "no"
  }, /*#__PURE__*/React.createElement(SandpackProvider, {
    template: template === 'react' ? 'react-ts' : template,
    files: files,
    options: sandpackProviderOptions,
    customSetup: customSetup
  }, /*#__PURE__*/React.createElement(SandpackThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(SandpackContent, null))));
}

function SandpackContent() {
  var _useState = useState(false),
      devToolsLoaded = _useState[0],
      setDevToolsLoaded = _useState[1];

  var _useState2 = useState(false),
      showDevTools = _useState2[0],
      changeShowDevTools = _useState2[1];

  var _useState3 = useState(false),
      isExpanded = _useState3[0],
      setIsExpanded = _useState3[1];

  var lineCountRef = useRef({});

  var _useActiveCode = useActiveCode(),
      code = _useActiveCode.code;

  var _useSandpack = useSandpack(),
      sandpack = _useSandpack.sandpack;

  var activeFile = sandpack.activeFile;

  if (!lineCountRef.current[activeFile] && code) {
    var _code$split;

    console.log('active', code);
    lineCountRef.current[activeFile] = code == null ? void 0 : code.split == null ? void 0 : (_code$split = code.split('\n')) == null ? void 0 : _code$split.length;
  }

  var lineCount = lineCountRef.current[activeFile];
  var isExpandable = lineCount > 16 || isExpanded;
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(NavigationBar, {
    showDevTools: showDevTools,
    changeShowDevTools: changeShowDevTools
  }), /*#__PURE__*/React.createElement("div", {
    className: "taro-hooks--sandpack__layout flex sp-layout sp-declaration",
    style: isExpanded ? {
      maxHeight: 'unset'
    } : {}
  }, /*#__PURE__*/React.createElement(SandpackCodeEditor, {
    showLineNumbers: true,
    showInlineErrors: true,
    showTabs: false,
    showRunButton: false
  }), /*#__PURE__*/React.createElement(Preview, {
    isExpanded: isExpanded
  })), isExpandable && /*#__PURE__*/React.createElement("div", {
    className: "taro-hooks--sandpack__footer flex items-center"
  }, /*#__PURE__*/React.createElement("button", {
    className: "button button--active button--link",
    onClick: function onClick() {
      return setIsExpanded(!isExpanded);
    }
  }, /*#__PURE__*/React.createElement("span", {
    className: "flex"
  }, /*#__PURE__*/React.createElement(IconChevron, {
    displayDirection: isExpanded ? 'up' : 'down'
  }), isExpanded ? '收起' : '展开'))), showDevTools && /*#__PURE__*/React.createElement(SandpackReactDevTools, {
    onLoadedData: console.log
  }));
}

SandpackRoot.displayName = 'TaroHooksSandpack';
export default SandpackRoot;