function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

// template
import packageJSON from '../template/package.json';
import babelConfig from '../template/babel.config';
import appVue from '../template/app.vue';
import appReact from '../template/app.react';
import appConfig from '../template/app.config';
import appIndexHtml from '../template/app.index.html';
import pageIndexConfig from '../template/page.index.config';
import configIndex from '../template/config.index';
import configEnv from '../template/config.env';
/**
 * @description generate deps by framework
 * @param {SandpackPredefinedTemplate} framework
 * @param {string} deps
 * @returns {Record<string, string>} deps
 */

export function getDeps(framework, deps) {
  var _framework;

  // only deal react & vue, default react
  framework = (_framework = framework) != null ? _framework : 'react'; // default use 3.4.8 taro version

  var defaultDeps = _extends({
    '@babel/runtime': '^7.7.7',
    '@tarojs/cli': '3.4.8',
    '@tarojs/components': '3.4.8',
    '@tarojs/react': '3.4.8',
    '@tarojs/runtime': '3.4.8',
    '@tarojs/taro': '3.4.8'
  }, generatePropsDeps(deps));

  if (framework === 'react') {
    return _extends({}, defaultDeps, {
      react: '^17.0.2',
      'react-dom': '^17.0.2',
      '@tarojs/plugin-framework-react': '3.4.8'
    });
  } else if (framework === 'vue3') {
    return _extends({}, defaultDeps, {
      '@tarojs/plugin-framework-vue3': '3.4.8',
      vue: '^3.0.0'
    });
  }

  return defaultDeps;
}
/**
 * @description generate devDeps by framework
 * @param {SandpackPredefinedTemplate} framework
 * @returns {Record<string, string>} devDeps
 */

export function getDevDeps(framework) {
  var _framework2;

  // only deal react & vue, default react
  framework = (_framework2 = framework) != null ? _framework2 : 'react'; // default use 3.4.8 taro version

  var defaultDeps = {
    '@babel/core': '^7.8.0',
    '@tarojs/mini-runner': '3.4.8',
    '@tarojs/webpack-runner': '3.4.8',
    '@types/webpack-env': '^1.13.6',
    '@typescript-eslint/eslint-plugin': '^5.20.0',
    '@typescript-eslint/parser': '^5.20.0',
    'babel-plugin-import': '^1.13.3',
    'babel-preset-taro': '3.4.8',
    eslint: '^8.12.0',
    'eslint-config-taro': '3.4.8',
    'eslint-plugin-import': '^2.12.0',
    stylelint: '9.3.0',
    typescript: '^4.6.3'
  };

  if (framework === 'react') {
    return _extends({}, defaultDeps, {
      '@types/react': '^17.0.2',
      'eslint-plugin-react': '^7.8.2',
      'eslint-plugin-react-hooks': '^4.2.0'
    });
  } else if (framework === 'vue3') {
    return _extends({}, defaultDeps, {
      'eslint-plugin-vue': '^8.0.0',
      'vue-loader': '^16.0.0-beta.8',
      '@vue/compiler-sfc': '^3.0.0'
    });
  }

  return defaultDeps;
}
/**
 * generate props.deps
 * @param {JSON string} deps
 * @returns {Record<string, string>} deps
 */

export function generatePropsDeps(deps) {
  if (deps === void 0) {
    deps = '';
  }

  var generateDeps = {};

  try {
    generateDeps = JSON.parse(deps);

    if (Object.prototype.toString.call(generateDeps) !== '[object Object]') {
      generateDeps = {};
    }
  } catch (e) {
    console.warn('generatePropsDeps error', e);
    generateDeps = {};
  }

  return generateDeps;
}
export function addOnFiles(files, template) {
  var addOnFiles = _extends({}, files); // addon package.json


  addOnFiles['/package.json'] = {
    code: JSON.stringify(packageJSON, null, 2)
  }; // add babel.config.js

  addOnFiles['/babel.config.js'] = {
    code: babelConfig(template)
  }; // add src/app.ts

  addOnFiles['/src/app.ts'] = {
    code: template === 'react' ? appReact : appVue
  }; // add app.config.ts

  addOnFiles['/src/app.config.ts'] = {
    code: appConfig
  }; // add index.html

  addOnFiles['/src/index.html'] = {
    code: appIndexHtml
  }; // add page/index/index.config.ts

  addOnFiles['/src/pages/index/index.config.ts'] = {
    code: pageIndexConfig
  }; // add config/index.js

  addOnFiles['/config/index.js'] = {
    code: configIndex(template)
  }; // add config/dev.js

  addOnFiles['/config/dev.js'] = {
    code: configEnv('development')
  }; // add config/prod.js

  addOnFiles['/config/prod.js'] = {
    code: configEnv('production')
  };
  return addOnFiles;
}