"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var tslib_1 = require("tslib");

var react_1 = tslib_1.__importStar(require("react"));

var sandpack_react_1 = require("@codesandbox/sandpack-react");

var sandpack_client_1 = require("@codesandbox/sandpack-client");

var NavigationBar_1 = tslib_1.__importDefault(require("./NavigationBar"));

var Preview_1 = tslib_1.__importDefault(require("./Preview"));

var IconChevron_1 = tslib_1.__importDefault(require("./IconChevron"));

var createFileMap_1 = require("../utils/createFileMap");

var getDeps_1 = require("../utils/getDeps");

var style_1 = require("../style");

function SandpackRoot(props) {
  var _files$AppCss$code, _files$AppCss;

  var children = props.children,
      code = props.code,
      filePath = props.filePath,
      frameWork = props.frameWork,
      dependencies = props.dependencies,
      editUrl = props.editUrl,
      theme = props.theme,
      _props$externalResour = props.externalResources,
      externalResources = _props$externalResour === void 0 ? [] : _props$externalResour;
  var template = frameWork || 'react';
  var sandpackProviderOptions = {
    autorun: true,
    logLevel: sandpack_client_1.SandpackLogLevel.None,
    initMode: 'user-visible',
    initModeObserverOptions: {
      rootMargin: '1400px 0px'
    },
    externalResources: externalResources
  };
  var customSetup = {
    dependencies: (0, getDeps_1.getDeps)(template, dependencies),
    devDependencies: (0, getDeps_1.getDevDeps)(template),
    entry: '/src/app.ts'
  };
  var codeSnippets = react_1.Children.toArray(children);
  var files = (0, createFileMap_1.createFileMap)(codeSnippets);

  if (code) {
    var extraFilePath = "/src/pages/index/index." + (template === 'react' ? 'tsx' : 'vue');
    files[extraFilePath] = {
      code: code,
      active: true,
      hidden: false,
      editUrl: editUrl
    };

    if (filePath) {
      sandpackProviderOptions.activeFile = extraFilePath;
      sandpackProviderOptions.visibleFiles = [extraFilePath];
    }
  } // addon styles.css


  files['/src/app.css'] = {
    code: [style_1.sandpackStyle, (_files$AppCss$code = (_files$AppCss = files['/app.css']) == null ? void 0 : _files$AppCss.code) != null ? _files$AppCss$code : ''].join('\n\n'),
    hidden: true
  }; // add extra setting files

  files = (0, getDeps_1.addOnFiles)(files, template);
  return react_1["default"].createElement("div", {
    className: "taro-hooks--sandpack",
    translate: "no"
  }, react_1["default"].createElement(sandpack_react_1.SandpackProvider, {
    template: template === 'react' ? 'react-ts' : template,
    files: files,
    options: sandpackProviderOptions,
    customSetup: customSetup
  }, react_1["default"].createElement(sandpack_react_1.SandpackThemeProvider, {
    theme: theme
  }, react_1["default"].createElement(SandpackContent, null))));
}

function SandpackContent() {
  var _ref = (0, react_1.useState)(false),
      devToolsLoaded = _ref[0],
      setDevToolsLoaded = _ref[1];

  var _ref2 = (0, react_1.useState)(false),
      showDevTools = _ref2[0],
      changeShowDevTools = _ref2[1];

  var _ref3 = (0, react_1.useState)(false),
      isExpanded = _ref3[0],
      setIsExpanded = _ref3[1];

  var lineCountRef = (0, react_1.useRef)({});

  var _ref4 = (0, sandpack_react_1.useActiveCode)(),
      code = _ref4.code;

  var _ref5 = (0, sandpack_react_1.useSandpack)(),
      sandpack = _ref5.sandpack;

  var activeFile = sandpack.activeFile;

  if (!lineCountRef.current[activeFile] && code) {
    var _code$split;

    console.log('active', code);
    lineCountRef.current[activeFile] = code == null ? void 0 : code.split == null ? void 0 : (_code$split = code.split('\n')) == null ? void 0 : _code$split.length;
  }

  var lineCount = lineCountRef.current[activeFile];
  var isExpandable = lineCount > 16 || isExpanded;
  return react_1["default"].createElement(react_1["default"].Fragment, null, react_1["default"].createElement(NavigationBar_1["default"], {
    showDevTools: showDevTools,
    changeShowDevTools: changeShowDevTools
  }), react_1["default"].createElement("div", {
    className: "taro-hooks--sandpack__layout flex sp-layout sp-declaration",
    style: isExpanded ? {
      maxHeight: 'unset'
    } : {}
  }, react_1["default"].createElement(sandpack_react_1.SandpackCodeEditor, {
    showLineNumbers: true,
    showInlineErrors: true,
    showTabs: false,
    showRunButton: false
  }), react_1["default"].createElement(Preview_1["default"], {
    isExpanded: isExpanded
  })), isExpandable && react_1["default"].createElement("div", {
    className: "taro-hooks--sandpack__footer flex items-center"
  }, react_1["default"].createElement("button", {
    className: "button button--active button--link",
    onClick: function onClick() {
      return setIsExpanded(!isExpanded);
    }
  }, react_1["default"].createElement("span", {
    className: "flex"
  }, react_1["default"].createElement(IconChevron_1["default"], {
    displayDirection: isExpanded ? 'up' : 'down'
  }), isExpanded ? '收起' : '展开'))), showDevTools && react_1["default"].createElement(sandpack_react_1.SandpackReactDevTools, {
    onLoadedData: console.log
  }));
}

SandpackRoot.displayName = 'TaroHooksSandpack';
exports["default"] = SandpackRoot;