"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createFileMap = void 0;

var createFileMap = function createFileMap(codeSnippets) {
  return codeSnippets.reduce(function (result, codeSnippet) {
    if (codeSnippet.props.mdxType !== 'pre') {
      return result;
    }

    var props = codeSnippet.props.children.props;
    var filePath; // path in the folder structure

    var fileHidden = false; // if the file is available as a tab

    var fileActive = false; // if the file tab is shown by default

    if (props.metastring) {
      var _props$metastring$spl = props.metastring.split(' '),
          name = _props$metastring$spl[0],
          params = _props$metastring$spl.slice(1);

      var fileName = name.startsWith('title') ? name.replace(/title=|"/g, '') : name;
      filePath = '/' + fileName;

      if (params.includes('hidden')) {
        fileHidden = true;
      }

      if (params.includes('active')) {
        fileActive = true;
      }
    } else {
      if (props.className === 'language-html') {
        filePath = '/App.vue';
      } else if (props.className === 'language-js') {
        filePath = '/App.js';
      } else if (props.className === 'language-css') {
        filePath = '/styles.css';
      } else {
        throw new Error("Code block is missing a filename: " + props.children);
      }
    }

    if (result[filePath]) {
      throw new Error("File " + filePath + " was defined multiple times. Each file snippet should have a unique path name");
    }

    result[filePath] = {
      code: props.children,
      hidden: fileHidden,
      active: fileActive
    };
    return result;
  }, {});
};

exports.createFileMap = createFileMap;