"use strict";

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.addOnFiles = exports.generatePropsDeps = exports.getDevDeps = exports.getDeps = void 0;

var tslib_1 = require("tslib"); // template


var package_json_1 = tslib_1.__importDefault(require("../template/package.json"));

var babel_config_1 = tslib_1.__importDefault(require("../template/babel.config"));

var app_vue_1 = tslib_1.__importDefault(require("../template/app.vue"));

var app_react_1 = tslib_1.__importDefault(require("../template/app.react"));

var app_config_1 = tslib_1.__importDefault(require("../template/app.config"));

var app_index_html_1 = tslib_1.__importDefault(require("../template/app.index.html"));

var page_index_config_1 = tslib_1.__importDefault(require("../template/page.index.config"));

var config_index_1 = tslib_1.__importDefault(require("../template/config.index"));

var config_env_1 = tslib_1.__importDefault(require("../template/config.env"));
/**
 * @description generate deps by framework
 * @param {SandpackPredefinedTemplate} framework
 * @param {string} deps
 * @returns {Record<string, string>} deps
 */


function getDeps(framework, deps) {
  var _framework;

  // only deal react & vue, default react
  framework = (_framework = framework) != null ? _framework : 'react'; // default use 3.4.8 taro version

  var defaultDeps = _extends({
    '@babel/runtime': '^7.7.7',
    '@tarojs/cli': '3.4.8',
    '@tarojs/components': '3.4.8',
    '@tarojs/react': '3.4.8',
    '@tarojs/runtime': '3.4.8',
    '@tarojs/taro': '3.4.8'
  }, generatePropsDeps(deps));

  if (framework === 'react') {
    return _extends({}, defaultDeps, {
      react: '^17.0.2',
      'react-dom': '^17.0.2',
      '@tarojs/plugin-framework-react': '3.4.8'
    });
  } else if (framework === 'vue3') {
    return _extends({}, defaultDeps, {
      '@tarojs/plugin-framework-vue3': '3.4.8',
      vue: '^3.0.0'
    });
  }

  return defaultDeps;
}

exports.getDeps = getDeps;
/**
 * @description generate devDeps by framework
 * @param {SandpackPredefinedTemplate} framework
 * @returns {Record<string, string>} devDeps
 */

function getDevDeps(framework) {
  var _framework2;

  // only deal react & vue, default react
  framework = (_framework2 = framework) != null ? _framework2 : 'react'; // default use 3.4.8 taro version

  var defaultDeps = {
    '@babel/core': '^7.8.0',
    '@tarojs/mini-runner': '3.4.8',
    '@tarojs/webpack-runner': '3.4.8',
    '@types/webpack-env': '^1.13.6',
    '@typescript-eslint/eslint-plugin': '^5.20.0',
    '@typescript-eslint/parser': '^5.20.0',
    'babel-plugin-import': '^1.13.3',
    'babel-preset-taro': '3.4.8',
    eslint: '^8.12.0',
    'eslint-config-taro': '3.4.8',
    'eslint-plugin-import': '^2.12.0',
    stylelint: '9.3.0',
    typescript: '^4.6.3'
  };

  if (framework === 'react') {
    return _extends({}, defaultDeps, {
      '@types/react': '^17.0.2',
      'eslint-plugin-react': '^7.8.2',
      'eslint-plugin-react-hooks': '^4.2.0'
    });
  } else if (framework === 'vue3') {
    return _extends({}, defaultDeps, {
      'eslint-plugin-vue': '^8.0.0',
      'vue-loader': '^16.0.0-beta.8',
      '@vue/compiler-sfc': '^3.0.0'
    });
  }

  return defaultDeps;
}

exports.getDevDeps = getDevDeps;
/**
 * generate props.deps
 * @param {JSON string} deps
 * @returns {Record<string, string>} deps
 */

function generatePropsDeps(deps) {
  if (deps === void 0) {
    deps = '';
  }

  var generateDeps = {};

  try {
    generateDeps = JSON.parse(deps);

    if (Object.prototype.toString.call(generateDeps) !== '[object Object]') {
      generateDeps = {};
    }
  } catch (e) {
    console.warn('generatePropsDeps error', e);
    generateDeps = {};
  }

  return generateDeps;
}

exports.generatePropsDeps = generatePropsDeps;

function addOnFiles(files, template) {
  var addOnFiles = _extends({}, files); // addon package.json


  addOnFiles['/package.json'] = {
    code: JSON.stringify(package_json_1["default"], null, 2)
  }; // add babel.config.js

  addOnFiles['/babel.config.js'] = {
    code: (0, babel_config_1["default"])(template)
  }; // add src/app.ts

  addOnFiles['/src/app.ts'] = {
    code: template === 'react' ? app_react_1["default"] : app_vue_1["default"]
  }; // add app.config.ts

  addOnFiles['/src/app.config.ts'] = {
    code: app_config_1["default"]
  }; // add index.html

  addOnFiles['/src/index.html'] = {
    code: app_index_html_1["default"]
  }; // add page/index/index.config.ts

  addOnFiles['/src/pages/index/index.config.ts'] = {
    code: page_index_config_1["default"]
  }; // add config/index.js

  addOnFiles['/config/index.js'] = {
    code: (0, config_index_1["default"])(template)
  }; // add config/dev.js

  addOnFiles['/config/dev.js'] = {
    code: (0, config_env_1["default"])('development')
  }; // add config/prod.js

  addOnFiles['/config/prod.js'] = {
    code: (0, config_env_1["default"])('production')
  };
  return addOnFiles;
}

exports.addOnFiles = addOnFiles;